@@ -1,5 +1,5 @@
-#' as.mcmc Extract mcmc object from the result of MHmcmc to be used with coda package
-#' @title Extract mcmc object from the result of MHmcmc to be used with coda package
+#' as.mcmc Extract mcmc object from the result of phenology_MHmcmc to be used with coda package
+#' @title Extract mcmc object from the result of phenology_MHmcmc to be used with coda package
 #' @author Marc Girondot
 #' @return A mcmc.list object
 #' @param x A result MHmcmc search
@@ -17,7 +17,7 @@
 as.mcmc.mcmcComposite <-
 function(x) {
 	if (class(x)!="mcmcComposite") {
-		print("mcmcComposite object must be provided.")
+		warning("mcmcComposite object must be provided")
 	
 	} else {
 
